def print_lol(the_list,level):
    """This function takes a positional argument called"the_list",which is any
    Python list(of,possibly,nested lists).Each data item in the provided list
    is(recursively) printed to the screenon its own line.
    A second argument called "level" is used to insert tab_stops when a nested
    list is encountered"""
    for each_item in the_list:
        if isinstance(each_item,list):
            print_lol(each_item,level+1)
        else:
            for tab_stop in range(level):
                print("\t",end=' ') 
            print(each_item)



import setuptools


'''from distutils.core import setup'''
with open("README.md","r") as fh:
    long_description=fh.read()

setuptools.setup(
    name              ='nestgo',
    version           ='1.1.0',
    py_modules        =['nestgo'],
    description       ='A simple printer of nested lists',
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
     )
